==> ory_client-1.1.2.tar.gz: test/project_branding_theme_test.dart <==
import 'package:test/test.dart';
import 'package:ory_client/ory_client.dart';

// tests for ProjectBrandingTheme
void main() {
  final instance = ProjectBrandingThemeBuilder();
  // TODO add properties to the builder and call build()

  group(ProjectBrandingTheme, () {
    // AccentDefaultColor is a hex color code used by the Ory Account Experience theme.
    // String accentDefaultColor
    test('to test the property `accentDefaultColor`', () async {
      // TODO
    });

    // AccentDisabledColor is a hex color code used by the Ory Account Experience theme.
    // String accentDisabledColor
    test('to test the property `accentDisabledColor`', () async {
      // TODO
    });

    // AccentEmphasisColor is a hex color code used by the Ory Account Experience theme.
    // String accentEmphasisColor
    test('to test the property `accentEmphasisColor`', () async {
      // TODO
    });

    // AccentMutedColor is a hex color code used by the Ory Account Experience theme.
    // String accentMutedColor
    test('to test the property `accentMutedColor`', () async {
      // TODO
    });

    // AccentSubtleColor is a hex color code used by the Ory Account Experience theme.
    // String accentSubtleColor
    test('to test the property `accentSubtleColor`', () async {
      // TODO
    });

    // BackgroundCanvasColor is a hex color code used by the Ory Account Experience theme.
    // String backgroundCanvasColor
    test('to test the property `backgroundCanvasColor`', () async {
      // TODO
    });

    // BackgroundSubtleColor is a hex color code used by the Ory Account Experience theme.
    // String backgroundSubtleColor
    test('to test the property `backgroundSubtleColor`', () async {
      // TODO
    });

    // BackgroundSurfaceColor is a hex color code used by the Ory Account Experience theme.
    // String backgroundSurfaceColor
    test('to test the property `backgroundSurfaceColor`', () async {
      // TODO
    });

    // BorderDefaultColor is a hex color code used by the Ory Account Experience theme.
    // String borderDefaultColor
    test('to test the property `borderDefaultColor`', () async {
      // TODO
    });

    // The Customiation Creation Date
    // DateTime createdAt
    test('to test the property `createdAt`', () async {
      // TODO
    });

    // ErrorDefaultColor is a hex color code used by the Ory Account Experience theme.
    // String errorDefaultColor
    test('to test the property `errorDefaultColor`', () async {
      // TODO
    });

    // ErrorEmphasisColor is a hex color code used by the Ory Account Experience theme.
    // String errorEmphasisColor
    test('to test the property `errorEmphasisColor`', () async {
      // TODO
    });

    // ErrorMutedColor is a hex color code used by the Ory Account Experience theme.
    // String errorMutedColor
    test('to test the property `errorMutedColor`', () async {
      // TODO
    });

    // ErrorSubtleColor is a hex color code used by the Ory Account Experience theme.
    // String errorSubtleColor
    test('to test the property `errorSubtleColor`', () async {
      // TODO
    });

    // ForegroundDefaultColor is a hex color code used by the Ory Account Experience theme.
    // String foregroundDefaultColor
    test('to test the property `foregroundDefaultColor`', () async {
      // TODO
    });

    // ForegroundDisabledColor is a hex color code used by the Ory Account Experience theme.
    // String foregroundDisabledColor
    test('to test the property `foregroundDisabledColor`', () async {
      // TODO
    });

    // ForegroundMutedColor is a hex color code used by the Ory Account Experience theme.
    // String foregroundMutedColor
    test('to test the property `foregroundMutedColor`', () async {
      // TODO
    });

    // ForegroundOnAccentColor is a hex color code used by the Ory Account Experience theme.
    // String foregroundOnAccentColor
    test('to test the property `foregroundOnAccentColor`', () async {
      // TODO
    });

    // ForegroundOnDarkColor is a hex color code used by the Ory Account Experience theme.
    // String foregroundOnDarkColor
    test('to test the property `foregroundOnDarkColor`', () async {
      // TODO
    });

    // ForegroundOnDisabledColor is a hex color code used by the Ory Account Experience theme.
    // String foregroundOnDisabledColor
    test('to test the property `foregroundOnDisabledColor`', () async {
      // TODO
    });

    // ForegroundSubtleColor is a hex color code used by the Ory Account Experience theme.
    // String foregroundSubtleColor
    test('to test the property `foregroundSubtleColor`', () async {
      // TODO
    });

    // The customization theme ID.
    // String id
    test('to test the property `id`', () async {
      // TODO
    });

    // InputBackgroundColor is a hex color code used by the Ory Account Experience theme.
    // String inputBackgroundColor
    test('to test the property `inputBackgroundColor`', () async {
      // TODO
    });

    // InputDisabledColor is a hex color code used by the Ory Account Experience theme.
    // String inputDisabledColor
    test('to test the property `inputDisabledColor`', () async {
      // TODO
    });

    // InputPlaceholderColor is a hex color code used by the Ory Account Experience theme.
    // String inputPlaceholderColor
    test('to test the property `inputPlaceholderColor`', () async {
      // TODO
    });

    // InputTextColor is a hex color code used by the Ory Account Experience theme.
    // String inputTextColor
    test('to test the property `inputTextColor`', () async {
      // TODO
    });

    // Logo Type The Logo mime type.
    // String logoType
    test('to test the property `logoType`', () async {
      // TODO
    });

    // Logo URL Logo can be an https:// or base64:// URL. If the URL is not allowed, the logo will be stored inside the Ory Network storage bucket.
    // String logoUrl
    test('to test the property `logoUrl`', () async {
      // TODO
    });

    // The customization theme name.
    // String name
    test('to test the property `name`', () async {
      // TODO
    });

    // Primary color is an hsla color value used to derive the other colors from for the Ory Account Experience theme.
    // String primaryColor
    test('to test the property `primaryColor`', () async {
      // TODO
    });

    // The ProjectBranding ID this customization is associated with
    // String projectBrandingId
    test('to test the property `projectBrandingId`', () async {
      // TODO
    });

    // Secondary color is a hsla color code used to derive the other colors from for the Ory Account Experience theme.
    // String secondaryColor
    test('to test the property `secondaryColor`', () async {
      // TODO
    });

    // SuccessEmphasisColor is a hex color code used by the Ory Account Experience theme.
    // String successEmphasisColor
    test('to test the property `successEmphasisColor`', () async {
      // TODO
    });

    // TextDefaultColor is a hex color code used by the Ory Account Experience theme.
    // String textDefaultColor
    test('to test the property `textDefaultColor`', () async {
      // TODO
    });

    // TextDisabledColor is a hex color code used by the Ory Account Experience theme.
    // String textDisabledColor
    test('to test the property `textDisabledColor`', () async {
      // TODO
    });

    // Last Time Branding was Updated
    // DateTime updatedAt
    test('to test the property `updatedAt`', () async {
      // TODO
    });

  });
}

==> ory_client-1.1.45.tar.gz: test/project_branding_theme_test.dart <==
import 'package:test/test.dart';
import 'package:ory_client/ory_client.dart';

// tests for ProjectBrandingTheme
void main() {
  final instance = ProjectBrandingThemeBuilder();
  // TODO add properties to the builder and call build()

  group(ProjectBrandingTheme, () {
    // AccentDefaultColor is a hex color code used by the Ory Account Experience theme.
    // String accentDefaultColor
    test('to test the property `accentDefaultColor`', () async {
      // TODO
    });

    // AccentDisabledColor is a hex color code used by the Ory Account Experience theme.
    // String accentDisabledColor
    test('to test the property `accentDisabledColor`', () async {
      // TODO
    });

    // AccentEmphasisColor is a hex color code used by the Ory Account Experience theme.
    // String accentEmphasisColor
    test('to test the property `accentEmphasisColor`', () async {
      // TODO
    });

    // AccentMutedColor is a hex color code used by the Ory Account Experience theme.
    // String accentMutedColor
    test('to test the property `accentMutedColor`', () async {
      // TODO
    });

    // AccentSubtleColor is a hex color code used by the Ory Account Experience theme.
    // String accentSubtleColor
    test('to test the property `accentSubtleColor`', () async {
      // TODO
    });

    // BackgroundCanvasColor is a hex color code used by the Ory Account Experience theme.
    // String backgroundCanvasColor
    test('to test the property `backgroundCanvasColor`', () async {
      // TODO
    });

    // BackgroundSubtleColor is a hex color code used by the Ory Account Experience theme.
    // String backgroundSubtleColor
    test('to test the property `backgroundSubtleColor`', () async {
      // TODO
    });

    // BackgroundSurfaceColor is a hex color code used by the Ory Account Experience theme.
    // String backgroundSurfaceColor
    test('to test the property `backgroundSurfaceColor`', () async {
      // TODO
    });

    // BorderDefaultColor is a hex color code used by the Ory Account Experience theme.
    // String borderDefaultColor
    test('to test the property `borderDefaultColor`', () async {
      // TODO
    });

    // The Customization Creation Date.
    // DateTime createdAt
    test('to test the property `createdAt`', () async {
      // TODO
    });

    // ErrorDefaultColor is a hex color code used by the Ory Account Experience theme.
    // String errorDefaultColor
    test('to test the property `errorDefaultColor`', () async {
      // TODO
    });

    // ErrorEmphasisColor is a hex color code used by the Ory Account Experience theme.
    // String errorEmphasisColor
    test('to test the property `errorEmphasisColor`', () async {
      // TODO
    });

    // ErrorMutedColor is a hex color code used by the Ory Account Experience theme.
    // String errorMutedColor
    test('to test the property `errorMutedColor`', () async {
      // TODO
    });

    // ErrorSubtleColor is a hex color code used by the Ory Account Experience theme.
    // String errorSubtleColor
    test('to test the property `errorSubtleColor`', () async {
      // TODO
    });

    // ForegroundDefaultColor is a hex color code used by the Ory Account Experience theme.
    // String foregroundDefaultColor
    test('to test the property `foregroundDefaultColor`', () async {
      // TODO
    });

    // ForegroundDisabledColor is a hex color code used by the Ory Account Experience theme.
    // String foregroundDisabledColor
    test('to test the property `foregroundDisabledColor`', () async {
      // TODO
    });

    // ForegroundMutedColor is a hex color code used by the Ory Account Experience theme.
    // String foregroundMutedColor
    test('to test the property `foregroundMutedColor`', () async {
      // TODO
    });

    // ForegroundOnAccentColor is a hex color code used by the Ory Account Experience theme.
    // String foregroundOnAccentColor
    test('to test the property `foregroundOnAccentColor`', () async {
      // TODO
    });

    // ForegroundOnDarkColor is a hex color code used by the Ory Account Experience theme.
    // String foregroundOnDarkColor
    test('to test the property `foregroundOnDarkColor`', () async {
      // TODO
    });

    // ForegroundOnDisabledColor is a hex color code used by the Ory Account Experience theme.
    // String foregroundOnDisabledColor
    test('to test the property `foregroundOnDisabledColor`', () async {
      // TODO
    });

    // ForegroundSubtleColor is a hex color code used by the Ory Account Experience theme.
    // String foregroundSubtleColor
    test('to test the property `foregroundSubtleColor`', () async {
      // TODO
    });

    // The customization theme ID.
    // String id
    test('to test the property `id`', () async {
      // TODO
    });

    // InputBackgroundColor is a hex color code used by the Ory Account Experience theme.
    // String inputBackgroundColor
    test('to test the property `inputBackgroundColor`', () async {
      // TODO
    });

    // InputDisabledColor is a hex color code used by the Ory Account Experience theme.
    // String inputDisabledColor
    test('to test the property `inputDisabledColor`', () async {
      // TODO
    });

    // InputPlaceholderColor is a hex color code used by the Ory Account Experience theme.
    // String inputPlaceholderColor
    test('to test the property `inputPlaceholderColor`', () async {
      // TODO
    });

    // InputTextColor is a hex color code used by the Ory Account Experience theme.
    // String inputTextColor
    test('to test the property `inputTextColor`', () async {
      // TODO
    });

    // Logo Type The Logo mime type.
    // String logoType
    test('to test the property `logoType`', () async {
      // TODO
    });

    // Logo URL Logo can be an https:// or base64:// URL. If the URL is not allowed, the logo will be stored inside the Ory Network storage bucket.
    // String logoUrl
    test('to test the property `logoUrl`', () async {
      // TODO
    });

    // The customization theme name.
    // String name
    test('to test the property `name`', () async {
      // TODO
    });

    // Primary color is an hsla color value used to derive the other colors from for the Ory Account Experience theme.
    // String primaryColor
    test('to test the property `primaryColor`', () async {
      // TODO
    });

    // The ProjectBranding ID this customization is associated with.
    // String projectBrandingId
    test('to test the property `projectBrandingId`', () async {
      // TODO
    });

    // Secondary color is a hsla color code used to derive the other colors from for the Ory Account Experience theme.
    // String secondaryColor
    test('to test the property `secondaryColor`', () async {
      // TODO
    });

    // SuccessEmphasisColor is a hex color code used by the Ory Account Experience theme.
    // String successEmphasisColor
    test('to test the property `successEmphasisColor`', () async {
      // TODO
    });

    // TextDefaultColor is a hex color code used by the Ory Account Experience theme.
    // String textDefaultColor
    test('to test the property `textDefaultColor`', () async {
      // TODO
    });

    // TextDisabledColor is a hex color code used by the Ory Account Experience theme.
    // String textDisabledColor
    test('to test the property `textDisabledColor`', () async {
      // TODO
    });

    // Last Time Branding was Updated.
    // DateTime updatedAt
    test('to test the property `updatedAt`', () async {
      // TODO
    });

  });
}
